@@ -18,11 +18,11 @@ con_weights <- function(cov, meq) {
 ## compute weights based on simulation.
 ## REF: Silvapulle and Sen (2005, p. 79). Constrained Statistical Inference: Order, 
 ## Inequality, and Shape Constraints. Hoboken, {NJ}: Wiley
-con_weights_boot <- function(VCOV, Amat, meq, 
+con_weights_boot <- function(VCOV, Amat, meq,
                              R = 99999L, parallel = c("no", "multicore", "snow"),
-                             ncpus = 1L, cl = NULL, seed = NULL, 
+                             ncpus = 1L, cl = NULL, seed = NULL,
                              verbose = FALSE, ...) {
-  
+
   parallel <- match.arg(parallel)
   have_mc <- have_snow <- FALSE
   if (parallel != "no" && ncpus > 1L) {
@@ -31,30 +31,26 @@ con_weights_boot <- function(VCOV, Amat, meq,
     else if (parallel == "snow")
       have_snow <- TRUE
     if (!have_mc && !have_snow)
-      ncpus <- 1L  
+      ncpus <- 1L
     }
-  
-  if (!is.null(seed))
-    set.seed(seed)
-  if (!exists(".Random.seed", envir = .GlobalEnv))
-    runif(1)
-  RNGstate <- .Random.seed
-  
-  
+
+  if (!is.null(seed)) set.seed(seed)
+  if (!exists(".Random.seed", envir = .GlobalEnv)) runif(1)
+
   bvec <- rep(0L, nrow(Amat)) # weights do not depend on bvec.
-  invW <- solve(VCOV) 
+  invW <- solve(VCOV)
   Dmat <- 2*invW
   Z <- rmvnorm(n = R, mean = rep(0, ncol(VCOV)), sigma = VCOV)
   dvec <- 2*(Z %*% invW)
-  
-  
+
+
   fn <- function(b) {
-    QP <- try(solve.QP(Dmat = Dmat, 
-                       dvec = dvec[b, ], 
+    QP <- try(solve.QP(Dmat = Dmat,
+                       dvec = dvec[b, ],
                        Amat = t(Amat),
-                       bvec = bvec, 
+                       bvec = bvec,
                        meq  = meq), silent = TRUE)
-    
+
     if (inherits(QP, "try-error")) {
       if (verbose) cat("quadprog FAILED\n")
       return(NULL)
@@ -62,16 +58,15 @@ con_weights_boot <- function(VCOV, Amat, meq,
       if (verbose) {
         cat(" ...active inequality constraints =", QP$iact, "\n")
       }
-      
-    }    
-    
+    }
+
     if (QP$iact[1] == 0L) {
-      return(0L) 
-    } else { 
+      return(0L)
+    } else {
       return(length(QP$iact))
-    }  
+    }
   }
-  
+
   RR <- sum(R)
   res <- if (ncpus > 1L && (have_mc || have_snow)) {
     if (have_mc) {
@@ -79,45 +74,47 @@ con_weights_boot <- function(VCOV, Amat, meq,
     }
     else if (have_snow) {
       if (is.null(cl)) {
-        cl <- parallel::makePSOCKcluster(rep("localhost",
-                                             ncpus))
+        cl <- parallel::makePSOCKcluster(rep("localhost", ncpus))
         if (RNGkind()[1L] == "L'Ecuyer-CMRG")
           parallel::clusterSetRNGStream(cl)
-        
+
         res <- parallel::parLapply(cl, seq_len(RR), fn)
         parallel::stopCluster(cl)
         res
-      } else { 
+      } else {
         parallel::parLapply(cl, seq_len(RR), fn)
       }
     }
   }
-  else lapply(seq_len(RR), fn) 
-  
-  error.idx <- integer(0)
-  iact <- vector("numeric", ncol(Amat))
-  
-  for (b in seq_len(R)) {
-    if (!is.null(res[[b]])) {
-      iact[b] <- res[[b]]
-    }
-    else {
-      error.idx <- c(error.idx, b)
-    }
-  }
-  
+  else lapply(seq_len(RR), fn)
+
+  # error.idx <- integer(0)
+  # iact <- vector("numeric", ncol(Amat))
+  #
+  # for (b in seq_len(R)) {
+  #   if (!is.null(res[[b]])) {
+  #     iact[b] <- res[[b]]
+  #   }
+  #   else {
+  #     error.idx <- c(error.idx, b)
+  #   }
+  # }
+
   # compute the number of positive components of VCOV.
   # ncol(VCOV) = maximum number of constraints
   # iact       = number of active inequality constraints
+  iact <- sapply(res, function(x) ifelse(is.null(x), NA, x))
+  error.idx <- which(is.na(iact))
+
+  dimL <- ncol(VCOV) - iact
   if (length(error.idx) > 0) {
     dimL <- ncol(VCOV) - iact[-error.idx]
   } else {
     dimL <- ncol(VCOV) - iact
   }
+
   wt.bar <- sapply(0:ncol(VCOV), function(x) sum(x == dimL)) / length(dimL)
   attr(wt.bar, "error.idx") <- error.idx
-  
+
   wt.bar
-}
-
-
+}
\ No newline at end of file
